# eric7.Plugins.VcsPlugins.vcsSubversion.SvnDiffHighlighter

Module implementing a syntax highlighter for unified and context diff outputs.

### Global Attributes

None

### Classes

SvnDiffHighlighter | Class implementing a diff highlighter for Git.

### Functions

None

## SvnDiffHighlighter

Class implementing a diff highlighter for Git.

### Derived from

EricGenericDiffHighlighter

### Class Attributes

None

### Class Methods

None

### Methods

SvnDiffHighlighter | Constructor
generateRules | Public method to generate the rule set.

### Static Methods

None

#### SvnDiffHighlighter (Constructor)

SvnDiffHighlighter(doc)

Constructor

doc
  reference to the text document (QTextDocument)

#### SvnDiffHighlighter.generateRules

generateRules()

Public method to generate the rule set.

Up